@@ -39,11 +39,14 @@ class Provider(object):
         resp.close()
         return content
 
-    def request(self, url, **extra_params):
+    def encode_params(self, url, **extra_params):
         params = dict(self.base_params)
         params.update(extra_params)
         params['url'] = url
-        encoded_params = urlencode(sorted(params.items()))
+        return urlencode(sorted(params.items()))
+
+    def request(self, url, **extra_params):
+        encoded_params = self.encode_params(url, **extra_params)
 
         endpoint_url = self.endpoint
         if '?' in endpoint_url:
@@ -53,13 +56,16 @@ class Provider(object):
 
         response = self.fetch(endpoint_url)
         if response:
-            json_data = json.loads(response)
-            if 'url' not in json_data:
-                json_data['url'] = url
-            return json_data
+            return self.handle_response(response, url)
         else:
             raise ProviderException('Error fetching "%s"' % endpoint_url)
 
+    def handle_response(self, response, url):
+        json_data = json.loads(response)
+        if 'url' not in json_data:
+            json_data['url'] = url
+        return json_data
+
 
 def make_key(*args, **kwargs):
     return hashlib.md5(pickle.dumps((args, kwargs))).hexdigest()
@@ -85,7 +91,7 @@ class ProviderRegistry(object):
         self._registry[regex] = provider
 
     def unregister(self, regex):
-        del(self._registry[index])
+        del(self._registry[regex])
 
     def __iter__(self):
         return iter(self._registry.items())
@@ -104,11 +110,19 @@ class ProviderRegistry(object):
 
 
 def bootstrap_basic(cache=None):
+    # complements of oembed.com#section7
     pr = ProviderRegistry(cache)
     pr.register('http://\S*?flickr.com/\S*', Provider('http://www.flickr.com/services/oembed/'))
     pr.register('http://\S*.youtu(\.be|be\.com)/watch\S*', Provider('http://www.youtube.com/oembed'))
+    pr.register('http://\S*.viddler.com/\S*', Provider('http://lab.viddler.com/services/oembed/'))
+    pr.register('http://qik.com/video/\S*', Provider('http://qik.com/api/oembed.json'))
+    pr.register('http://\S*.revision3.com/\S*', Provider('http://revision3.com/api/oembed/'))
     pr.register('http://www.hulu.com/watch/\S*', Provider('http://www.hulu.com/api/oembed.json'))
     pr.register('http://vimeo.com/\S*', Provider('http://vimeo.com/api/oembed.json'))
+    pr.register('http://www.polleverywhere.com/(polls|multiple_choice_polls|free_text_polls)/\S*', Provider('http://www.polleverywhere.com/services/oembed/'))
+    pr.register('http://www.ifixit.com/Guide/View/\S*', Provider('http://www.ifixit.com/Embed'))
+    pr.register('http://\S*.smugmug.com/\S*', Provider('http://api.smugmug.com/services/oembed/'))
+    pr.register('http://\S+.wordpress.com/\S+', Provider('http://public-api.wordpress.com/oembed/'))
     pr.register('http://www.slideshare.net/[^\/]+/\S*', Provider('http://www.slideshare.net/api/oembed/2'))
     return pr
 
